@@ -2,20 +2,22 @@ from __future__ import annotations
 
 from argparse import ArgumentParser
 from importlib.metadata import version
+from typing import Sequence
 
 import pandas as pd
 
-from .load import load_tb_events
-from .write import write_data_file, write_tb_events
+from tensorboard_reducer.load import load_tb_events
+from tensorboard_reducer.write import write_data_file, write_tb_events
 
 
 def reduce_events(
-    events_dict: dict[str, pd.DataFrame], reduce_ops: list[str]
+    events_dict: dict[str, pd.DataFrame], reduce_ops: Sequence[str]
 ) -> dict[str, dict[str, pd.DataFrame]]:
-    """Perform numpy reduce ops on the last axis of each array in a dictionary of
-    scalar TensorBoard event data. Each array enters
-    this function with shape (n_timesteps, r_runs) and len(reduce_ops) exit
-    with shape (n_timesteps,).
+    """Perform numpy reduce operations along the last dimension of each array in a
+    dictionary of scalar TensorBoard event data. Each array (1 per run) enters this
+    function with shape (n_steps, n_runs) and it returns a dict of len(reduce_ops)
+    subdicts each with keys named after scalar quantities (loss, accuracy, etc.) holding
+    arrays with shape (n_steps,).
 
     Args:
         events_dict (dict[str, pd.DataFrame]): Dict of arrays to reduce.
@@ -29,17 +31,15 @@ def reduce_events(
     reductions: dict[str, dict[str, pd.DataFrame]] = {}
 
     for op in reduce_ops:
-
         reductions[op] = {}
 
         for tag, df in events_dict.items():
-
             reductions[op][tag] = getattr(df, op)(axis=1)
 
     return reductions
 
 
-def main(argv: list[str] = None) -> int:
+def main(argv: list[str] | None = None) -> int:
     """Implement tb-reducer CLI.
 
     Args:
@@ -163,13 +163,11 @@ def main(argv: list[str] = None) -> int:
     reduced_events = reduce_events(events_dict, reduce_ops)
 
     if outpath.endswith(".csv"):
-
         write_data_file(reduced_events, outpath, overwrite)
 
         print(f"Wrote {', '.join(reduce_ops)} reductions to '{outpath}'")
 
     else:
-
         write_tb_events(reduced_events, outpath, overwrite)
 
         for op in reduce_ops:
