@@ -4,10 +4,11 @@ import os
 from typing import Any
 
 import pandas as pd
-from torch.utils.tensorboard import SummaryWriter
+
+_known_extensions = (".csv", ".json", ".xls", ".xlsx")
 
 
-def rm_rf_or_raise(path: str, overwrite: bool) -> None:
+def _rm_rf_or_raise(path: str, overwrite: bool) -> None:
     """Remove the directory tree below dir if overwrite is True.
 
     Args:
@@ -18,7 +19,6 @@ def rm_rf_or_raise(path: str, overwrite: bool) -> None:
         FileExistsError: If path exists and overwrite=False.
     """
     if os.path.exists(path):  # True if dir is either file or directory
-
         # for safety, check dir is either TensorBoard run or CSV file
         # to make it harder to delete files not created by this program
         is_tb_dir = os.path.isdir(path) and all(
@@ -26,7 +26,7 @@ def rm_rf_or_raise(path: str, overwrite: bool) -> None:
         )
         # use `ext in path` instead of endswith() to handle compressed files
         # (.csv.gz, .json.bz2, etc.)
-        is_data_file = any(ext in path.lower() for ext in [".csv", ".json"])
+        is_data_file = any(ext in path.lower() for ext in _known_extensions)
 
         if overwrite and (is_data_file or is_tb_dir):
             os.system(f"rm -rf {path}")
@@ -45,12 +45,12 @@ def rm_rf_or_raise(path: str, overwrite: bool) -> None:
 
 def write_tb_events(
     data_to_write: dict[str, dict[str, pd.DataFrame]],
-    outdir: str,
+    out_dir: str,
     overwrite: bool = False,
-) -> None:
-    """Writes a dictionary with tags as keys and reduced TensorBoard scalar data as
-    values to disk as a new TensorBoard event file in a newly created or overwritten
-    `outdir` directory (depending on `overwrite`).
+) -> list[str]:
+    """Write a dictionary with tags as keys and reduced TensorBoard scalar data
+    as values to disk as a new TensorBoard event file in a newly created or
+    overwritten `out_dir` directory (depending on `overwrite`).
 
     Inspired by https://stackoverflow.com/a/48774926.
 
@@ -58,41 +58,59 @@ def write_tb_events(
         data_to_write (dict[str, dict[str, pd.DataFrame]]): Data to write to disk.
             Assumes 1st-level keys are reduce ops (mean, std, ...) and 2nd-level are
             TensorBoard tags.
-        outdir (str): Name of the directory to save the new reduced run data. Will
+        out_dir (str): Name of the directory to save the new reduced run data. Will
             have the reduce op name (e.g. '-mean'/'-std') appended.
         overwrite (bool): Whether to overwrite existing reduction directories.
             Defaults to False.
+
+    Returns:
+        list[str]: List of paths to the new TensorBoard event files.
     """
+    try:
+        from torch.utils.tensorboard import SummaryWriter
+    except ImportError:
+        try:
+            from tensorflow.summary import SummaryWriter
+        except ImportError:
+            raise ImportError(
+                "Cannot import SummaryWriter from torch nor tensorflow."
+                "Install either to create new TensorBoard event files."
+            )
+    out_dirs: list[str] = []
+    data_to_write = data_to_write.copy()  # make copy since we modify std data in place
+
+    out_dir_op_connector = "" if out_dir.endswith(("/", "\\")) else "-"
+
     # handle std reduction separately as we use writer.add_scalars to write mean +/- std
-    if "mean" in data_to_write.keys() and "std" in data_to_write.keys():
-
-        std_dict = data_to_write.pop("std")
+    if {"mean", "std"}.issubset(data_to_write):
         mean_dict = data_to_write["mean"]
+        # remove std from data_to_write so we don't write it twice
+        std_dict = data_to_write.pop("std")
 
-        std_dir = f"{outdir}-std"
+        for sign, symbol in ((1, "+"), (-1, "-")):
+            std_out_dir = f"{out_dir}{out_dir_op_connector}mean{symbol}std"
 
-        rm_rf_or_raise(std_dir, overwrite)
+            _rm_rf_or_raise(std_out_dir, overwrite)
+            out_dirs.append(std_out_dir)
 
-        writer = SummaryWriter(std_dir)
+            writer = SummaryWriter(std_out_dir)
 
-        for (tag, means), stds in zip(mean_dict.items(), std_dict.values()):
-            # we can safely zip(means, stds): they have the same length and same step
-            # values because the same data went into both reductions
-            for (step, mean), std in zip(means.items(), stds.to_numpy()):
-                writer.add_scalars(
-                    tag, {"mean+std": mean + std, "mean-std": mean - std}, step
-                )
+            for (tag, means), stds in zip(mean_dict.items(), std_dict.values()):
+                # we can safely zip(means, stds): they have the same length and same
+                # step values because the same data went into both reductions
+                for (step, mean), std in zip(means.items(), stds.to_numpy()):
+                    writer.add_scalar(tag, mean + sign * std, step)
 
         writer.close()
 
     # loop over each reduce operation (e.g. mean, min, max, median)
     for op, events_dict in data_to_write.items():
+        op_out_dir = f"{out_dir}{out_dir_op_connector}{op}"
+        out_dirs.append(op_out_dir)
 
-        op_outdir = f"{outdir}-{op}"
+        _rm_rf_or_raise(op_out_dir, overwrite)
 
-        rm_rf_or_raise(op_outdir, overwrite)
-
-        writer = SummaryWriter(op_outdir)
+        writer = SummaryWriter(op_out_dir)
 
         for tag, series in events_dict.items():
             for step, value in series.items():
@@ -100,11 +118,13 @@ def write_tb_events(
 
         # Important for allowing write_events() to overwrite. Without it,
         # try_rmtree will raise OSError: [Errno 16] Device or resource busy
-        # trying to delete the existing outdir.
+        # trying to delete the existing out_dir.
         writer.close()
 
+    return out_dirs
 
-def write_df(*args: Any, **kwargs: Any) -> None:
+
+def write_df(*args: Any) -> None:
     """Inform users of breaking change if they try to use the old API."""
     raise NotImplementedError(
         "write_df() was renamed to write_data_file() in tensorboard-reducer v0.2.8"
@@ -125,13 +145,13 @@ def write_data_file(
         data_to_write (dict[str, dict[str, pd.DataFrame]]): Data to write to disk.
             Assumes 1st-level keys are reduce ops (mean, std, ...) and 2nd-level are
             TensorBoard tags.
-        out_path (str): CSV or JSON file path where the reduced data will be written.
-            Supports all compression formats that Pandas supports. Simply change the
-            file extension. For example .csv.gz, .csv.gzip, .json.bz2, json.tar, etc.
+        out_path (str): CSV, JSON or Excel file path where the reduced data will be
+            written. Supports all compression formats that Pandas supports. Simply
+            change the file extension. For example .csv.gz, .csv.gzip, .json.bz2, etc.
         overwrite (bool): Whether to overwrite existing reduction directories.
             Defaults to False.
     """
-    rm_rf_or_raise(out_path, overwrite)
+    _rm_rf_or_raise(out_path, overwrite)
 
     # create multi-index dataframe from event data with reduce op names as 1st-level col
     # names and tag names as 2nd level
@@ -146,7 +166,10 @@ def write_data_file(
         df.to_csv(out_path)
     elif ".json" in basename.lower():
         df.to_json(out_path)
+    elif ".xls" in out_path.lower():
+        df.to_excel(out_path)
     else:
         raise ValueError(
-            f"Unknown extension in {out_path=}, should include .csv or .json"
+            f"{out_path=} has unknown extension, should be one of {_known_extensions} "
+            " or compressed versions thereof like '.csv.gz', '.json.bz2', etc."
         )
